EnvLoader class
Loads a .env asset file from the Flutter asset bundle and parses it.
Delegates parsing to EnvParser. Throws EnvLoadException when the asset cannot be found or read.
Constructors
- EnvLoader({AssetBundle? bundle})
-
Creates an EnvLoader backed by the given
_bundle.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
load(
String path) → Future< Map< String, String> > -
Loads and parses the
.envfile atpath. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited