currentNotifier property
A ValueNotifier that broadcasts the currently active E whenever the
environment is switched. Useful for reactive UI updates.
Implementation
final ValueNotifier<E> currentNotifier;
A ValueNotifier that broadcasts the currently active E whenever the
environment is switched. Useful for reactive UI updates.
final ValueNotifier<E> currentNotifier;