getDouble method
Returns the value for key as a double.
Throws EnvKeyNotFoundException if the key is absent, or
FormatException if the value cannot be parsed as a double.
Implementation
double getDouble(String key) => double.parse(get(key));
Returns the value for key as a double.
Throws EnvKeyNotFoundException if the key is absent, or
FormatException if the value cannot be parsed as a double.
double getDouble(String key) => double.parse(get(key));