getInt method
Returns the value for key as an int.
Throws EnvKeyNotFoundException if the key is absent, or
FormatException if the value cannot be parsed as an integer.
Implementation
int getInt(String key) => int.parse(get(key));
Returns the value for key as an int.
Throws EnvKeyNotFoundException if the key is absent, or
FormatException if the value cannot be parsed as an integer.
int getInt(String key) => int.parse(get(key));