getDouble static method
Returns the value for key parsed as a double.
Throws EnvKeyNotFoundException or FormatException.
Implementation
static double getDouble(String key) => EnvManager.instance.getDouble(key);
Returns the value for key parsed as a double.
Throws EnvKeyNotFoundException or FormatException.
static double getDouble(String key) => EnvManager.instance.getDouble(key);