getInt static method
Returns the value for key parsed as an int.
Throws EnvKeyNotFoundException or FormatException.
Implementation
static int getInt(String key) => EnvManager.instance.getInt(key);
Returns the value for key parsed as an int.
Throws EnvKeyNotFoundException or FormatException.
static int getInt(String key) => EnvManager.instance.getInt(key);