onRequest method
Called when the request is about to be sent.
Implementation
@override
void onRequest(
RequestOptions options,
RequestInterceptorHandler handler,
) {
options.baseUrl = Env.get(baseUrlKey);
handler.next(options);
}
Called when the request is about to be sent.
@override
void onRequest(
RequestOptions options,
RequestInterceptorHandler handler,
) {
options.baseUrl = Env.get(baseUrlKey);
handler.next(options);
}