models/env_exceptions library

Exceptions / Errors

EnvKeyNotFoundException
Thrown when Env.get (or typed variants) is called with a key that does not exist in the currently loaded environment.
EnvLoadException
Thrown when Env.init is called but a config asset cannot be loaded.
EnvNotInitializedException
Thrown when an Env accessor is called before Env.init has completed.
EnvSwitchLockedException
Thrown when Env.switchTo or EnvManager.switchTo is called while the current environment is included in the lockedEnvironments set.