EnvKeyNotFoundException class

Thrown when Env.get (or typed variants) is called with a key that does not exist in the currently loaded environment.

Implemented types

Constructors

EnvKeyNotFoundException(String key, {String? envName})
Creates an EnvKeyNotFoundException for the given key.
const

Properties

envName String?
The name of the environment that was queried (optional, for diagnostics).
final
hashCode int
The hash code for this object.
no setterinherited
key String
The missing key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited