EnvLoadException class
Thrown when Env.init is called but a config asset cannot be loaded.
- Implemented types
Constructors
- EnvLoadException(String message)
-
Creates an EnvLoadException with the given
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited