enabled property
Whether the debug panel gesture is active.
Set to false to unconditionally disable the gesture regardless of
build mode.
Implementation
final bool enabled;
Whether the debug panel gesture is active.
Set to false to unconditionally disable the gesture regardless of
build mode.
final bool enabled;