onSwitched property
Optional callback fired after the environment switch (and optional app restart) completes.
Useful for triggering analytics events, showing a snackbar, etc.
Implementation
final VoidCallback? onSwitched;
Optional callback fired after the environment switch (and optional app restart) completes.
Useful for triggering analytics events, showing a snackbar, etc.
final VoidCallback? onSwitched;