EnvStore class
Persists and restores the selected environment identifier string using
SharedPreferences.
The stored value is the raw .name of the user's enum — it is the
caller's responsibility to convert back to the enum value.
Constructors
- EnvStore()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - Clears the persisted selection.
-
load(
) → Future< String?> -
Restores the previously saved env name, or
nullif nothing is saved. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
String value) → Future< void> -
Persists
value(the enum's.name) toSharedPreferences. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited