currentNotifier property
ValueNotifier
get
currentNotifier
A ValueNotifier that emits the active environment whenever it changes.
Useful for driving reactive widgets without wrapping the entire app:
ValueListenableBuilder(
valueListenable: Env.currentNotifier,
builder: (context, env, _) => Text(env.name),
)
Implementation
static ValueNotifier<dynamic> get currentNotifier =>
EnvManager.instance.currentNotifier;