EnvDioInterceptor class

A Dio Interceptor that injects BASE_URL from the active environment into every outgoing request.

Peer dependency: dio is not a hard dependency of flutter_env_switch. Add it to your own pubspec.yaml:

dependencies:
  dio: ^5.0.0

Usage

final dio = Dio()..interceptors.add(EnvDioInterceptor());

By default, the interceptor reads 'BASE_URL' from the active env. You can customise the key with the baseUrlKey constructor parameter.

Constructors

EnvDioInterceptor({String baseUrlKey = 'BASE_URL'})
Creates an EnvDioInterceptor.
const

Properties

baseUrlKey String
The .env key whose value is used as options.baseUrl.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
inherited
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited