EnvLoadException class

Thrown when Env.init is called but a config asset cannot be loaded.

Implemented types

Constructors

EnvLoadException(String message)
Creates an EnvLoadException with the given message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the load failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited