ui/debug_panel library
Classes
- AppRestarter
- A StatefulWidget that enables soft app restart by rebuilding its subtree.
Functions
-
showEnvDebugPanel<
E extends Enum> (BuildContext context, {bool showRestartToggle = true, VoidCallback? onSwitched}) → Future< void> - Shows the envify debug panel as a modal bottom sheet.